#####################################
Lake Shore 331 Temperature Controller
#####################################

.. autoclass:: pymeasure.instruments.lakeshore.LakeShore331
    :members:
    :show-inheritance: